/**
 * The result yielded during a recursive loop.
 * @export
 * @class RecursionResult
 * @template K
 * @template V
 * @template O
 */
export declare class RecursionResult<K, V, O extends object> {
    private _value;
    private _key;
    private _path;
    private _parent;
    private _previous;
    constructor(_value: V, _key: K, _path: string, _parent: O | null, _previous: RecursionResult<K, V, O> | null);
    /**
     * The value yielded.
     * @readonly
     * @type {V}
     */
    readonly value: V;
    /**
     * The key used to access the value yielded
     * @readonly
     * @type {K}
     */
    readonly key: K;
    /**
     * The path string used to access the yielded value from the root data object.
     * @readonly
     * @type {string}
     */
    readonly path: string;
    /**
     * The parent object of the value yielded.
     * @readonly
     * @type {(O | null)}
     */
    readonly parent: O | null;
    /**
     * The previous yielded result. This may or may not be the parent value.
     * @readonly
     * @type {(RecursionResult<K, V, O> | null)}
     */
    readonly previous: RecursionResult<K, V, O> | null;
}
