"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * The result yielded during a recursive loop.
 * @export
 * @class RecursionResult
 * @template K
 * @template V
 * @template O
 */
class RecursionResult {
    constructor(_value, _key, _path, _parent, _previous) {
        this._value = _value;
        this._key = _key;
        this._path = _path;
        this._parent = _parent;
        this._previous = _previous;
    }
    /**
     * The value yielded.
     * @readonly
     * @type {V}
     */
    get value() {
        return this._value;
    }
    /**
     * The key used to access the value yielded
     * @readonly
     * @type {K}
     */
    get key() {
        return this._key;
    }
    /**
     * The path string used to access the yielded value from the root data object.
     * @readonly
     * @type {string}
     */
    get path() {
        return this._path;
    }
    /**
     * The parent object of the value yielded.
     * @readonly
     * @type {(O | null)}
     */
    get parent() {
        return this._parent;
    }
    /**
     * The previous yielded result. This may or may not be the parent value.
     * @readonly
     * @type {(RecursionResult<K, V, O> | null)}
     */
    get previous() {
        return this._previous;
    }
}
exports.RecursionResult = RecursionResult;
//# sourceMappingURL=RecursionResult.js.map